{- |
RevDecTime is a tiny utility which displays the current French Revolutionary Decimal Time (metric clock). In this representation, each day is divided into ten (decimal) hours, each hour into a hundred minutes and each minute into a hundred seconds. The author of this tiny tool thinks that this is more comfortable than duodecimal.
-}

-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- --
---- |
---- Module			: Main
---- Copyright		: (C) Kamil Stachowski <kamil.stachowski@gmail.com>
---- License		: GPL3+
---- Maintainer		: Kamil Stachowski <kamil.stachowski@gmail.com>
---- Stability		: unstable
---- Portability	: unportable
---- A French revolutionary decimal time (metric) clock.
-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- --


module Main (main) where


import System.Time


-- main =================================================================================


main :: IO ()
main = do
	nowClock <- getClockTime >>= toCalendarTime
	print $ toRevDecTime nowClock


-- data =================================================================================


-- | Holds decimal time.
data RevDecTime
	= RevDecTime {
	  decHour	:: Int
	, decMin	:: Int
	, decSec	:: Int
	}

-- --------------------------------------------------------------------------------------

instance Show RevDecTime where
	show (RevDecTime h m s) = show h ++ ":" ++ show m ++ ":" ++ show s


-- conversion ===========================================================================


-- | Extracts the time from CalendarTime and converts it to RevDecTime (= decimal time).
toRevDecTime :: CalendarTime -> RevDecTime
toRevDecTime (CalendarTime _ _ _ h m s p _ _ _ _ _)
	= RevDecTime (fst decH) (fst decM) (fst decS)
	where
	mt		= 10 * ( fl(h)/24 + fl(m)/1440 + fl(s)/86400 + fr(p)/86400000000000000 )
	decH	= getNext mt
	decM	= getNext (snd decH)
	decS	= getNext (snd decM)
	getNext x = (fst (properFraction x), 100 * snd (properFraction x))
	fl		= fromIntegral
	fr		= fromInteger
